==> ejc-core-3.0.0-20200410.080719-4-sources.jar: com/ejianc/framework/core/util/ExcelExport.java <==
package com.ejianc.framework.core.util;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Map;

import javax.servlet.http.HttpServletResponse;

import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.springframework.core.io.ClassPathResource;

import net.sf.jxls.exception.ParsePropertyException;
import net.sf.jxls.transformer.XLSTransformer;

public class ExcelExport {
	private ExcelExport(){
		System.out.println("============jxls导出===========");
	}
	private static ExcelExport excelExport=null;
	public synchronized static ExcelExport getInstance(){
		if(excelExport==null){
			excelExport=new ExcelExport();
		}
		return excelExport;
	}
	 
	public void download(String name, HttpServletResponse response){
		 try {
	         response.addHeader("Pargam", "no-cache");
	         response.addHeader("Cache-Control", "no-cache");
	         response.setHeader("Content-disposition", "attachment;success=true;filename ="+ new String(name.getBytes("GB2312"),"ISO-8859-1"));
	         BufferedInputStream bis = null;
	         BufferedOutputStream bos = null;
	         OutputStream fos = null;
	         InputStream fis = null;
	         File uploadFile = new File(name);
	         fis = new FileInputStream(uploadFile);
	         bis = new BufferedInputStream(fis);
	          fos = response.getOutputStream();
	         bos = new BufferedOutputStream(fos);
 	         int bytesRead = 0;
	         byte[] buffer = new byte[8192];
 	         while ((bytesRead = bis.read(buffer, 0, 8192)) != -1) {
	             bos.write(buffer, 0, bytesRead);
	         }
	         bos.flush();
	         fis.close();
	         bis.close();
	         fos.close();
	         bos.close();
	         response.flushBuffer();
	     } catch (Exception e) {
	         e.printStackTrace();
	     }
	}
	
	/**
	 * 
	 * @param fileFileName 模板名称
	 * @param data 带导出的数据
	 * @param exitsName 导出excel的名称
	 * @throws InvalidFormatException 
	 */
	public void export(String exitsName,Map<String,Object> data,String fileFileName, HttpServletResponse response){
    	ClassPathResource resource = new ClassPathResource("static/"+exitsName);
		XLSTransformer transformer = new XLSTransformer();
	    try {
			transformer.transformXLS(resource.getFile().getAbsolutePath(), data, fileFileName);
		} catch (ParsePropertyException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} catch (InvalidFormatException e) {
			e.printStackTrace();
		}
	    ExcelExport.getInstance().download(fileFileName, response);
	}
}

==> ejc-core-3.0.0-20200415.004650-10-sources.jar: com/ejianc/framework/core/util/ExcelExport.java <==
package com.ejianc.framework.core.util;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Map;

import javax.servlet.http.HttpServletResponse;

import org.apache.poi.openxml4j.exceptions.InvalidFormatException;

import net.sf.jxls.exception.ParsePropertyException;
import net.sf.jxls.transformer.XLSTransformer;

public class ExcelExport {
	private ExcelExport(){
		System.out.println("============jxls导出===========");
	}
	private static ExcelExport excelExport=null;
	public synchronized static ExcelExport getInstance(){
		if(excelExport==null){
			excelExport=new ExcelExport();
		}
		return excelExport;
	}
	 
	public void download(String name, HttpServletResponse response){
		 try {
	         response.addHeader("Pargam", "no-cache");
	         response.addHeader("Cache-Control", "no-cache");
	         response.setHeader("Content-disposition", "attachment;success=true;filename ="+ new String(name.getBytes("GB2312"),"ISO-8859-1"));
	         BufferedInputStream bis = null;
	         BufferedOutputStream bos = null;
	         OutputStream fos = null;
	         InputStream fis = null;
	         File uploadFile = new File(name);
	         fis = new FileInputStream(uploadFile);
	         bis = new BufferedInputStream(fis);
	          fos = response.getOutputStream();
	         bos = new BufferedOutputStream(fos);
 	         int bytesRead = 0;
	         byte[] buffer = new byte[8192];
 	         while ((bytesRead = bis.read(buffer, 0, 8192)) != -1) {
	             bos.write(buffer, 0, bytesRead);
	         }
	         bos.flush();
	         fis.close();
	         bis.close();
	         fos.close();
	         bos.close();
	         response.flushBuffer();
	     } catch (Exception e) {
	         e.printStackTrace();
	     }
	}
	
	/**
	 * 
	 * @param fileFileName 模板名称
	 * @param data 带导出的数据
	 * @param exitsName 导出excel的名称
	 * @throws InvalidFormatException 
	 */
	public void export(String exitsName,Map<String,Object> data,String fileFileName, HttpServletResponse response){
		XLSTransformer transformer = new XLSTransformer();	
	    try {
	    	String path = getClass().getClassLoader().getResource("excel").getPath() + "/" + exitsName;
			transformer.transformXLS(path, data, fileFileName);
		} catch (ParsePropertyException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} catch (InvalidFormatException e) {
			e.printStackTrace();
		}
	    ExcelExport.getInstance().download(fileFileName, response);
	}
}
